==> twitter_api_py-0.1.0-py3-none-any.whl: twitter_api/client/request/request_client.py <==
from abc import ABCMeta, abstractmethod
from typing import Optional, Type

from twitter_api.rate_limit.manager.rate_limit_manager import RateLimitManager
from twitter_api.rate_limit.rate_limit_target import RateLimitTarget
from twitter_api.types.endpoint import Endpoint
from twitter_api.types.http import (
    Headers,
    QuryParameters,
    RequestJsonBody,
    ResponseModelBody,
    Url,
)
from twitter_api.types.oauth import OAuthVersion


class RequestClient(metaclass=ABCMeta):
    @property
    @abstractmethod
    def oauth_version(self) -> OAuthVersion:
        ...

    @property
    @abstractmethod
    def rate_limit_target(self) -> RateLimitTarget:
        ...

    @property
    @abstractmethod
    def rate_limit_manager(self) -> RateLimitManager:
        ...

    @abstractmethod
    def get(
        self,
        *,
        endpoint: Endpoint,
        response_type: Type[ResponseModelBody],
        url: Optional[Url] = None,
        auth: bool = True,
        query: Optional[QuryParameters] = None,
    ) -> ResponseModelBody:
        ...

    @abstractmethod
    def post(
        self,
        *,
        endpoint: Endpoint,
        response_type: Type[ResponseModelBody],
        url: Optional[Url] = None,
        auth: bool = True,
        headers: Optional[Headers] = None,
        query: Optional[QuryParameters] = None,
        body: Optional[RequestJsonBody] = None,
    ) -> ResponseModelBody:
        ...

    @abstractmethod
    def delete(
        self,
        *,
        endpoint: Endpoint,
        response_type: Type[ResponseModelBody],
        url: Optional[Url] = None,
        auth: bool = True,
        headers: Optional[Headers] = None,
        query: Optional[QuryParameters] = None,
    ) -> ResponseModelBody:
        ...

==> twitter_api_py-0.6.3-py3-none-any.whl: twitter_api/client/request/request_client.py <==
from abc import ABCMeta, abstractmethod
from typing import Optional, Type

from twitter_api.rate_limit.manager.rate_limit_manager import RateLimitManager
from twitter_api.rate_limit.rate_limit_target import RateLimitTarget
from twitter_api.types.endpoint import Endpoint
from twitter_api.types.http import (
    Headers,
    QuryParameters,
    RequestJsonBody,
    ResponseModelBody,
    Url,
)
from twitter_api.types.oauth import OAuthVersion


class RequestClient(metaclass=ABCMeta):
    @property
    @abstractmethod
    def oauth_version(self) -> OAuthVersion:
        ...

    @property
    @abstractmethod
    def rate_limit_target(self) -> RateLimitTarget:
        ...

    @property
    @abstractmethod
    def rate_limit_manager(self) -> RateLimitManager:
        ...

    @abstractmethod
    def get(
        self,
        *,
        endpoint: Endpoint,
        response_body_type: Type[ResponseModelBody],
        url: Optional[Url] = None,
        auth: bool = True,
        query: Optional[QuryParameters] = None,
    ) -> ResponseModelBody:
        ...

    @abstractmethod
    def post(
        self,
        *,
        endpoint: Endpoint,
        response_body_type: Type[ResponseModelBody],
        url: Optional[Url] = None,
        auth: bool = True,
        headers: Optional[Headers] = None,
        query: Optional[QuryParameters] = None,
        body: Optional[RequestJsonBody] = None,
    ) -> ResponseModelBody:
        ...

    @abstractmethod
    def delete(
        self,
        *,
        endpoint: Endpoint,
        response_body_type: Type[ResponseModelBody],
        url: Optional[Url] = None,
        auth: bool = True,
        headers: Optional[Headers] = None,
        query: Optional[QuryParameters] = None,
    ) -> ResponseModelBody:
        ...
